ExternalReference

Struct ExternalReference 

pub struct ExternalReference {
    pub external_reference_type: ExternalReferenceType,
    pub url: Uri,
    pub comment: Option<String>,
    pub hashes: Option<Hashes>,
}
Represents a way to document systems, sites, and information that may be relevant but which are not included with the BOM.

Please see the CycloneDX use case for more information and examples.

Fields

external_reference_type: ExternalReferenceTypeurl: Uricomment: Option<String>hashes: Option<Hashes>

Implementations

Source

impl ExternalReference

pub fn new( external_reference_type: ExternalReferenceType, url: impl Into<Uri>, ) -> Self

Constructs a new ExternalReference with the reference type and url

use cyclonedx_bom::models::external_reference::{ExternalReference, ExternalReferenceType};
use cyclonedx_bom::external_models::uri::Uri;

let url = Uri::new("https://example.org/support/sbom/portal-server/1.0.0");
let external_reference = ExternalReference::new(ExternalReferenceType::Bom, url);